@@ -1,5 +1,5 @@
 #!/usr/bin/python3
-# Usage: autosubset <font-file> < <used-text>
+# Usage: autosubset [options] <font-file> < <used-text>
 # * Automatically split the font file into two parts:
 #   1. The part that only provides the characters read from stdin, which will be
 #      used for the current version of the web page
@@ -12,7 +12,7 @@ import subprocess
 import sys
 
 
-VERSION = '0.2.0'
+VERSION = '0.2.1'
 
 
 def range_string(start, end):
@@ -49,26 +49,26 @@ def set2ranges(s):
 
 def get_args():
     parser = argparse.ArgumentParser(description="autosubset – "
-            "Automatically create an optimized subset font "
-            "using fonttool's pyftsubset")
+                                     "Automatically create an optimized subset font "
+                                     "using fonttool's pyftsubset")
     parser.add_argument('--version',
-            action='version', version=VERSION)
+                        action='version', version=VERSION)
     parser.add_argument('--digits',
-            action='store_true',
-            help="""Also include all digits, independent of whether they
+                        action='store_true',
+                        help="""Also include all digits, independent of whether they
                 appear in the input. This is useful if you also have some
                 counters elsewhere.""")
     parser.add_argument('--ascii-letters',
-            action='store_true',
-            help="""Also include a-z and A-Z, independent of whether they
+                        action='store_true',
+                        help="""Also include a-z and A-Z, independent of whether they
                 appear in the input.""")
-    parser.add_argument('--ascii-printable',
-            action='store_true',
-            help="""Also include space to tilde (0x20-0x7f), independent of
+    parser.add_argument('--ascii-printable', '--ascii',
+                        action='store_true',
+                        help="""Also include space to tilde (0x20-0x7f), independent of
                 whether they appear in the input.""")
     parser.add_argument('font_file',
-            nargs='+',
-            help="""The files to subset into <basename>.subset.woff2""")
+                        nargs='+',
+                        help="""The files to subset into <basename>.subset.woff2""")
     return parser.parse_args()
 
 
@@ -84,6 +84,8 @@ def main():
         char_ords = char_ords.union(range(0x20, 0x7f))
 
     ranges = set2ranges(char_ords)
+    html = ""
+    css = ""
     for full in args.font_file:
         dot = full.rindex('.')
         minus = full.find('-')
@@ -94,7 +96,10 @@ def main():
         fmt = full[dot+1:]
         subset = full[:dot] + '.subset' + full[dot:]
         subprocess.run(['pyftsubset', '--unicodes=' + ranges,
-            '--flavor=woff2', '--with-zopfli', full], check=True)
-        print(f"""<link rel="preload" href="{subset}" as "font" type="font/woff2">
+                        '--flavor=woff2', '--with-zopfli', full], check=True)
+        html += f"""
+<link rel="preload" href="{subset}" as="font" type="font/woff2" />"""
+        css += f"""
 @font-face {{ font-family: {base}; src: url({subset}) format(woff2); unicode-range: {ranges}; }}
-@font-face {{ font-family: {base}; src: url({full}) format({fmt}); }}""")
+@font-face {{ font-family: {base}; src: url({full}) format({fmt}); }}"""
+    print(f"// HTML code:{html}\n// CSS code:{css}")
